/**
 * Configuration module
 */

var fs = require("fs");
var path = require("path");

/**
 * Return a default configuration when config.json is not available
 *
 * @returns Default configuration object
 */
function defaultConfig()
{
	return {
		host: "localhost",
		port: 8000,
		prefix: "/",
		webRoot: path.resolve("."),
		defaultUrl: "/index.html",
		maxPostSize: 2097152,
		precompileViews: true,
		logDir: "./logs",
		accessible: [],
		fileUrlMap: {}
	};
}

var rootDir = path.dirname(require.main.filename);
var configData;

try {
	var configPath = path.join(rootDir, "bubble-config.json");

	console.info("Loading configuration from " + configPath);

	configData = JSON.parse(fs.readFileSync(configPath));

	console.info("Configuration loaded.");
} catch (e) {
	console.warn(e);
	console.warn("Default configuration loaded.");

	configData = defaultConfig();
}

module.exports = configData;
