/**
 * Error types
 */

var util = require("util");

/**
 * Abstract class for all errors
 *
 * @param {string} msg - Error message
 * @param {function} constructor - Error object constructor
 */
var AbstractError = function (msg, constructor) {
	Error.captureStackTrace(this, constructor || this);
	this.message = msg || "Error";
};

util.inherits(AbstractError, Error);
AbstractError.prototype.name = "AbstractError";

/**
 * Error when a file is not found
 *
 * @param {string} msg - Error message
 */
var FileNotFoundError = function (msg) {
	FileNotFoundError.super_.call(this, msg, this.constructor);
};

util.inherits(FileNotFoundError, AbstractError);
FileNotFoundError.prototype.name = "FileNotFoundError";

/**
 * Error when a route cannot be routed to any controller
 *
 * @param {string} msg - Error message
 */
var NoRouteToControllerError = function (msg) {
	NoRouteToControllerError.super_.call(this, msg, this.constructor);
};

util.inherits(NoRouteToControllerError, AbstractError);
NoRouteToControllerError.prototype.name = "NoRouteToControllerError";

/**
 * Error when a controller doesn't have specified action
 *
 * @param {string} msg - Error message
 */
var NoSuchActionError = function (msg) {
	NoSuchActionError.super_.call(this, msg, this.constructor);
};

util.inherits(NoSuchActionError, AbstractError);
NoSuchActionError.prototype.name = "NoSuchActionError";

/**
 * Error when an action cannot be accessed with requested method
 *
 * @param {string} msg - Error message
 */
var MethodNotAllowedError = function (msg) {
	MethodNotAllowedError.super_.call(this, msg, this.constructor);
};

util.inherits(MethodNotAllowedError, AbstractError);
MethodNotAllowedError.prototype.name = "MethodNotAllowedError";

/**
 * Error when an action is not authencated
 *
 * @param {string} msg - Error message
 */
var ActionNoAuthError = function (msg) {
	ActionNoAuthError.super_.call(this, msg, this.constructor);
};

util.inherits(ActionNoAuthError, AbstractError);
ActionNoAuthError.prototype.name = "ActionNoAuthError";

/**
 * Error when a POST request length is too long
 *
 * @param {string} msg - Error message
 */
var RequestTooLongError = function (msg) {
	RequestTooLongError.super_.call(this, msg, this.constructor);
};

util.inherits(RequestTooLongError, AbstractError);
RequestTooLongError.prototype.name = "RequestTooLongError";

exports.FileNotFound = FileNotFoundError;
exports.NoRouteToController = NoRouteToControllerError;
exports.NoSuchAction = NoSuchActionError;
exports.MethodNotAllowed = MethodNotAllowedError;
exports.ActionNoAuth = ActionNoAuthError;
exports.RequestTooLong = RequestTooLongError;