var mime = require("mime");
var configs = require("./conf/configs");
var fs = require("fs");
var path = require("path");
var errors = require("./errors");
var logger = require("./utils/logger").outputLogger;

function ExternalFileResolverController()
{
	'@controller { "urlPattern": "/externalFileResolver" }';

	this.externalFileResolver = function (callback, context) {
		'@action';

		var realPath = path.resolve(path.join(configs.webRoot, context.params.path));
		var allow = false;

		for (var i = 0; i < configs.accessible.length; i++) {
			var allowedPath = path.resolve(path.join(configs.webRoot, configs.accessible[i]));
			if (realPath.indexOf(allowedPath) === 0) {
				allow = true;
			}
		}

		if (!allow) {
			logger.warn("Path " + realPath + " is not allowed to access!");
			return callback(new errors.FileNotFound("Requested file " + context.params.path + " not found!"));
		}

		fs.stat(realPath, function (err, stats) {
			if (err) {
				return callback(err);
			}

			if (context.request.headers["if-modified-since"]) {
				var modifyCheckDate = Date.parse(context.request.headers["if-modified-since"]);

				if (modifyCheckDate >= stats.mtime) {
					context.response.writeHead(304);
					context.response.end();
					callback(null, null, null, 0, true);
					return;
				}
			}

			context.response.setHeader("Last-Modified", stats.mtime.toUTCString());

			callback(null, fs.createReadStream(realPath), mime.lookup(realPath), stats.size);
		});
	};
}

module.exports = ExternalFileResolverController;
