/**
 * Scan and load filters
 */

require("../utils/annotation");

var readdirp = require("readdirp");
var logger = require("../utils/logger").outputLogger;

/**
 * Scan a directory and load all filters found
 *
 * @param {string} root - Scan directory
 * @param {function} callback - Callback function with signature fn(err: Error, result: Array)
 */
function scan(root, callback)
{
	var result = [];

	readdirp({ root: root, fileFilter: "*.filter.js" })
		.on("data", function (entry) {
			var Filter = require(entry.fullPath);
			if (!Filter.hasAnnotation("filter")) {
				return;
			}

			var info = Filter.getAnnotationData("filter");
			result.push({ info: info, filter: new Filter() });
			logger.info("Loaded filter at " + entry.path);
		})
		.on("end", function () {
			callback(null, result);
		})
		.on("error", function (err) {
			callback(err);
		});
}

exports.scan = scan;
