if (global.testMode) {
	var dummyLogger = {
		info: function () {},
		warn: function () {},
		error: function () {}
	};

	exports.accessLogger = dummyLogger;
	exports.outputLogger = dummyLogger;
} else {
	var log4js = require("log4js");
	var configs = require("../conf/configs");
	var path = require("path");
	var mkdirp = require("mkdirp");
	var fs = require("fs");

	fs.stat(configs.logDir, function (err, stats) {
		var doConfLog = function () {
			console.info("Log directory: " + configs.logDir);

			log4js.configure({
				appenders: [
				    {
				    	type: "console"
				    },
				    {
				    	type: "dateFile",
				    	filename: path.join(configs.logDir, "access.log"),
				    	pattern: "-yyyy-MM-dd",
				    	alwaysIncludePattern: false,
				    	category: "access"
				    },
				    {
				    	type: "dateFile",
				    	filename: path.join(configs.logDir, "output.log"),
				    	pattern: "-yyyy-MM-dd",
				    	alwaysIncludePattern: false,
				    	category: "output"
				    }
				],
				replaceConsole: true
			});
		};

		var doCreatePath = function () {
			mkdirp(configs.logDir, function (err) {
				if (err) {
					console.error(err);
				}

				doConfLog();
			});
		};

		if (err) {
			return doCreatePath();
		}

		if (!stats.isDirectory) {
			fs.rmdir(configs.logDir, function (err) {
				if (err) {
					console.error(err);
				}

				doCreatePath();
			});
		} else {
			doConfLog();
		}
	});

	var accessLogger = log4js.getLogger("access");
	accessLogger.setLevel("ALL");

	var outputLogger = log4js.getLogger("output");
	outputLogger.setLevel("ALL");

	exports.accessLogger = accessLogger;
	exports.outputLogger = outputLogger;
}
