var dateFormat = require("dateformat");
var configs = require("../conf/configs");

function StringUtils()
{
    this.formatDate = function (date, format, utc) {
        if (!date) {
            return "";
        }

        return dateFormat(date, format, utc);
    };

    this.getDays = function (timespan) {
        if (!timespan) {
            return 0;
        }

        return Math.floor(timespan / (1000 * 60 * 60 * 24));
    };

    this.getLongestSemanticTime = function (timespan) {
        if (!timespan) {
            return {
                time: 0,
                unit: "s"
            };
        }

        var days = timespan / (1000 * 60 * 60 * 24);
        if (Math.abs(days) > 1) {
            var months = days / 30;
            if (Math.abs(months) < 1) {
                return {
                    time: Math.floor(days),
                    unit: "d"
                };
            } else {
                var years = months / 12;
                if (Math.abs(years) < 1) {
                    return {
                        time: Math.floor(months),
                        unit: "m"
                    };
                } else {
                    return {
                        time: Math.floor(years),
                        unit: "y"
                    };
                }
            }
        } else {
            var hours = days * 24;
            if (Math.abs(hours) < 1) {
                var minutes = hours * 60;
                if (Math.abs(minutes) < 1) {
                    return {
                        time: Math.floor(minutes * 60),
                        unit: "s"
                    };
                } else {
                    return {
                        time: Math.floor(minutes),
                        unit: "M"
                    };
                }
            } else {
                return {
                    time: Math.floor(hours),
                    unit: "H"
                };
            }
        }
    };

    this.defEmpty = function (str) {
        if (!str) {
            return "";
        }

        return str;
    };

    this.toContentRoot = function (url) {
        if (url.indexOf("/") === 0) {
            url = url.substring(1);
        }

        return configs.prefix + url;
    };
}

module.exports = StringUtils;
